/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef IN16_REMOTEMATLABREQ_H
#define IN16_REMOTEMATLABREQ_H

#include <Controller.h>
#include <cameo/cameo.h>

namespace in16 {

class FrequencyRemoteMatlabReq : public ExperimentController,
									public controller::Stoppable {

public:
	//! Type of controller
	static const std::string TYPE;

	FrequencyRemoteMatlabReq(const std::string& name);
	FrequencyRemoteMatlabReq(const FrequencyRemoteMatlabReq& controller);
	virtual ~FrequencyRemoteMatlabReq();

	virtual void postConfiguration();

	virtual void start();
	virtual void stop();

	static const std::string RUN_SPECTRUMS_TEST;
	static const std::string RUN_SPECTRUMS;
	static const std::string RUN_SPECTRUMS_TIME;
	static const std::string RUN_SINGLE_FREQUENCY;

	DynamicProperty<std::string> requestTypeValues;
	Property<std::string> requestType;

	Property<double> fr;
	Property<double> frMin;
	Property<double> frMax;
	Property<int32> nMax;
	Property<double> time;
	Property<std::string> comment;

private:
	bool initApplication();

	static const std::string MATLAB_APPLICATION;
	static const std::string RESPONDER_NAME;

	Property<std::string> serverEndpoint;
	Property<bool> initialized;

	std::auto_ptr<cameo::Server> m_server;
	std::auto_ptr<cameo::application::Instance> m_matlabApplication;
	std::auto_ptr<cameo::application::Requester> m_requester;
};

}

#endif
