/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "RunSpectrums.h"
#include "controllers/common/family/Families.h"

namespace in16 {

using namespace std;
using namespace common;

const std::string RunSpectrums::TYPE = "in16_run_spectrums";

RunSpectrums::RunSpectrums(const std::string& name) :
	ExperimentController(name), controller::Stoppable(this) {

	setFamily(family::ACQUISITION);

	fr.init(this, NOSAVE, "fr");
	frMin.init(this, NOSAVE, "frMin");
	frMax.init(this, NOSAVE, "frMax");
	nMax.init(this, NOSAVE, "nMax");
	time.init(this, NOSAVE, "time");
	comment.init(this, NOSAVE, "comment");

	matlabController.init(this, "matlab");
}

RunSpectrums::~RunSpectrums() {
}

void RunSpectrums::postConfiguration() {

}

void RunSpectrums::start() {

	matlabController->requestType = FrequencyRemoteMatlabReq::RUN_SPECTRUMS;
	matlabController->frMin = frMin();
	matlabController->frMax = frMax();
	matlabController->nMax = nMax();
	matlabController->comment = comment();

	matlabController->startCommand();
}

void RunSpectrums::stop() {

	matlabController->stopCommand();
}

}
